==> digiKam-7.6.0.tar.xz: digikam-7.6.0/core/dplugins/editor/transform/perspective/perspectivetoolplugin.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2018-07-30
 * Description : image editor plugin to adjust perspective.
 *
 * Copyright (C) 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_PERSPECTIVETOOL_PLUGIN_H
#define DIGIKAM_PERSPECTIVETOOL_PLUGIN_H

// Local includes

#include "dplugineditor.h"

#define DPLUGIN_IID "org.kde.digikam.plugin.editor.PerspectiveTool"

using namespace Digikam;

namespace DigikamEditorPerspectiveToolPlugin
{

class PerspectiveToolPlugin : public DPluginEditor
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID DPLUGIN_IID)
    Q_INTERFACES(Digikam::DPluginEditor)

public:

    explicit PerspectiveToolPlugin(QObject* const parent = nullptr);
    ~PerspectiveToolPlugin()             override;

    QString name()                 const override;
    QString iid()                  const override;
    QIcon   icon()                 const override;
    QString details()              const override;
    QString description()          const override;
    QList<DPluginAuthor> authors() const override;

    void setup(QObject* const)           override;

private Q_SLOTS:

    void slotPerspective();
};

} // namespace DigikamEditorPerspectiveToolPlugin

#endif // DIGIKAM_PERSPECTIVETOOL_PLUGIN_H

==> digiKam-8.3.0-1.tar.xz: digikam-8.3.0/core/dplugins/editor/transform/perspective/perspectivetoolplugin.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2018-07-30
 * Description : image editor plugin to adjust perspective.
 *
 * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * ============================================================ */

#ifndef DIGIKAM_PERSPECTIVETOOL_PLUGIN_H
#define DIGIKAM_PERSPECTIVETOOL_PLUGIN_H

// Local includes

#include "dplugineditor.h"

#define DPLUGIN_IID "org.kde.digikam.plugin.editor.PerspectiveTool"

using namespace Digikam;

namespace DigikamEditorPerspectiveToolPlugin
{

class PerspectiveToolPlugin : public DPluginEditor
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID DPLUGIN_IID)
    Q_INTERFACES(Digikam::DPluginEditor)

public:

    explicit PerspectiveToolPlugin(QObject* const parent = nullptr);
    ~PerspectiveToolPlugin()             override;

    QString name()                 const override;
    QString iid()                  const override;
    QIcon   icon()                 const override;
    QString details()              const override;
    QString description()          const override;
    QList<DPluginAuthor> authors() const override;
    QString handbookSection()      const override;
    QString handbookChapter()      const override;
    QString handbookReference()    const override;

    void setup(QObject* const)           override;

private Q_SLOTS:

    void slotPerspective();
};

} // namespace DigikamEditorPerspectiveToolPlugin

#endif // DIGIKAM_PERSPECTIVETOOL_PLUGIN_H
